@@ -34,7 +34,7 @@
 #' @return A list of test statistics, degrees of freedom, and p-values.
 #'  \item{test}{A numeric vector of gradient (GR), likelihood ratio (LR), Rao score (RS), and Wald test statistics.}
 #'  \item{df}{Degrees of freedom.}
-#'  \item{pvalue}{A numeric vector of corresponding p-values.}
+#'  \item{pvalue}{A vector of corresponding p-values.}
 #'  \item{call}{The matched call.}
 #' @references{
 #'  Fischer, G. H. (1995). The Linear Logistic Test Model. In G. H. Fischer & I. W. Molenaar (Eds.),
@@ -125,10 +125,12 @@ change_test <- function(X) {
 
   df <- 1
   pvalue <- 1 - (sapply(test.stats, stats::pchisq, df = df))
+  pvalue <- pvalr(pvalue, digits = 3)
 
   res.list <- list("test" = round(test.stats, digits = 3),
                    "df" = df,
-                   "pvalue" = round(pvalue, digits = 3),
+                   "pvalue" = pvalue,
+                   # "pvalue" = round(pvalue, digits = 3),
                    "call" = call)
 
   return(res.list)
