@@ -14,7 +14,7 @@
 # where one assumes all items presented to all persons.
 #
 # Licensed under the GNU General Public License Version 3 (June 2007)
-# copyright (c) 2021, Last Modified 24/04/2021
+# copyright (c) 2021, Last Modified 02/05/2023
 ######################################################################
 #' Test of invariance of item parameters between two groups.
 #'
@@ -22,6 +22,12 @@
 #'   for hypothesis of equality of item parameters between two groups of persons against a two-sided
 #'  alternative that at least one item parameter differs between the two groups.
 #'
+#'  Note that items are excluded for the computation of GR,LR, and W due to inappropriate
+#'  response patterns within subgroups and for computation of RS due to inappropriate
+#'  response patterns in the total data. If the model is identified from the total data but not from one
+#'  or both subgroups only RS will be computed. If the model is not identified from the total data,
+#'  no test statistic is computable.
+#'
 #' @param X Data matrix.
 #' @param splitcr Split criterion which is either "mean", "median" or a numeric vector x.
 #' \describe{
@@ -33,8 +39,9 @@
 #' @param model RM, PCM, RSM
 #' @return A list of test statistics, degrees of freedom, and p-values.
 #'  \item{test}{A numeric vector of gradient (GR), likelihood ratio (LR), Rao score (RS), and Wald test statistics.}
-#'  \item{df}{Degrees of freedom.}
-#'  \item{pvalue}{A numeric vector of corresponding p-values.}
+#'  \item{df}{A numeric vector of corresponding degrees of freedom.}
+#'  \item{pvalue}{A vector of corresponding p-values.}
+#'  \item{deleted_items}{A list with numeric vectors of item numbers that were excluded before computing corresponding test statistics.}
 #'  \item{call}{The matched call.}
 #'
 #' @references{
@@ -67,6 +74,36 @@
 #'res$test # test statistics
 #'res$df # degrees of freedoms
 #'res$pvalue # p-values
+#'res$deleted_items # excluded items
+#'
+#'$test
+#'   GR    LR    RS     W
+#'14.492 14.083 13.678 12.972
+#'
+#'$df
+#'GR LR RS  W
+#' 7  7  7  7
+#'
+#'$pvalue
+#'   GR    LR    RS     W
+#'"0.043" "0.050" "0.057" "0.073"
+#'
+#'$deleted_items
+#'  $deleted_items$GR
+#'  [1] "none"
+#'
+#'  $deleted_items$LR
+#'  [1] "none"
+#'
+#'  $deleted_items$RS
+#'  [1] "none"
+#'
+#'  $deleted_items$W
+#'  [1] "none"
+#'
+#'
+#'$call
+#'invar_test(X = y, splitcr = x, model = "RM")
 #'
 #'}
 
@@ -86,6 +123,13 @@ invar_test <- function(X, splitcr = "median", model = "RM"){
   #    - inappropriate response patterns within subgroups
   #    - ill-conditioned data matrix (restricted and unrestricted models)
   #---------------------------------------------------------------------
+
+  Xcheck<- tcl_datcheck_full(X,model)
+  if (Xcheck$Xcheck == "none") return(list("test" = NA, "df" = NA,"pvalue" = NA,
+                                           "deleted_items"=NA, "call" = call))
+  del_pos_full <- Xcheck$del_pos  # check full model
+  # if (any(!is.na(del_pos_full))) X <- X[,-del_pos_full]
+
   e <- tcl_splitcr(X = X, splitcr = splitcr, model = model)
   Xlist_check <- tcl_datcheck(X=X, Xlist = e$X.list, model = model)
 
@@ -99,14 +143,55 @@ invar_test <- function(X, splitcr = "median", model = "RM"){
 
   test_switch <- function(option) {
     switch(option,
-           "full" = invar_test_full(y, y1, y2, model),
-           "RS" = invar_test_RS(y, y1, y2, model),
-           "none" = list("test" = NA, "df" = NA,"pvalue" = NA, "call" = call),
+           "full" = invar_test_full(y=y, y1=y1, y2=y2, model=model, X=X, splitcr = splitcr, del_pos=del_pos_full),
+           # "RS" = invar_test_RS(y, y1, y2, model),
+           "RS" =  RStest(X=X, splitcr = splitcr, model=model,del_pos=del_pos_full), # addded AK 20-02-2022
+           "none" = list("test" = NA, "df" = NA,"pvalue" = NA,"deleted_items"=NA, "call" = call),
            stop("Invalid `option` value")
     )
   }
 
   res.list <- test_switch(option = Xlist_check)
-  res.list $call <- call
+
+  if(Xlist_check=="full") {
+    if(is.na(e$del_pos)) {
+      e$del_pos <- "none"
+    } else {
+      e$del_pos <-  paste0("I", e$del_pos)
+    }
+
+    if(is.na(del_pos_full))  {
+      del_pos_full <- "none"
+    } else {
+      del_pos_full <- paste0("I", del_pos_full)
+    }
+
+    res.list$deleted_items <- list("GR"=e$del_pos, "LR"=e$del_pos, "RS"=del_pos_full,"W"=e$del_pos) # added AK 20-02-2022
+  }
+
+  if(Xlist_check=="RS") {
+    test.stats <- c( NA, NA, res.list$RS, NA)
+    names(test.stats) <- c("GR", "LR", "RS", "W")
+
+    df_vec <- c(NA,NA,res.list$df,NA)
+    names(df_vec) <- c("GR", "LR", "RS", "W")
+
+    pvalue <- c(NA,NA,res.list$pvalue,NA)
+    names(pvalue) <- c("GR", "LR", "RS", "W")
+
+    if(is.na(del_pos_full))  {
+      del_pos_full <- "none"
+    } else {
+      del_pos_full <- paste0("I", del_pos_full)
+    }
+    pvalue <- pvalr(pvalue, digits = 3)
+
+    res.list <- list("test" = round(test.stats, digits = 3),
+                     "df" = df_vec,
+                     "pvalue" = pvalue,
+                     "deleted_items" = list(  "GR"=NA,"LR"=NA,"RS"=del_pos_full,"W"=NA)) # addded AK 20-02-2022
+  }
+
+  res.list$call <- call
   return(res.list)
 }
